summaryrefslogtreecommitdiffstats
path: root/kalarm/soundpicker.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/soundpicker.h')
-rw-r--r--kalarm/soundpicker.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kalarm/soundpicker.h b/kalarm/soundpicker.h
index a0a9b83c..eaf0ec16 100644
--- a/kalarm/soundpicker.h
+++ b/kalarm/soundpicker.h
@@ -30,9 +30,10 @@ class ComboBox;
class PushButton;
-class SoundPicker : public QFrame
+class SoundPicker : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Sound options which can be selected for when the alarm is displayed.
* @li NONE - silence.
@@ -42,10 +43,10 @@ class SoundPicker : public QFrame
*/
enum Type { NONE = 0, BEEP, PLAY_FILE, SPEAK };
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit SoundPicker(TQWidget* parent, const char* name = 0);
+ explicit SoundPicker(TQWidget* tqparent, const char* name = 0);
/** Initialises the widget's state.
* @param type The option to select.
* @param filename The full path or URL of the sound file to select. If the 'file' option is
@@ -103,7 +104,7 @@ class SoundPicker : public QFrame
* If null, no file will be highlighted.
* @return URL selected, in human readable format. If none is selected, URL.isEmpty() is true.
*/
- static TQString browseFile(TQString& initialDir, const TQString& initialFile = TQString::null);
+ static TQString browseFile(TQString& initialDir, const TQString& initialFile = TQString());
static TQString i18n_Sound(); // plain text of Sound label
static TQString i18n_None(); // plain text of None combo box item
@@ -42,10 +43,10 @@ class SoundPicker : public QFrame
enum Type { NONE = 0, BEEP, PLAY_FILE, SPEAK };
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/